@@ -62,10 +62,11 @@ wired_menu_item_info_destroy (gpointer data)
 
 #define DEFAULT_WIRED_NAME _("Auto Ethernet")
 
-static NMConnection *
+static gboolean
 wired_new_auto_connection (NMDevice *device,
-                           NMApplet *applet,
-                           gpointer user_data)
+                           gpointer dclass_data,
+                           AppletNewAutoConnectionCallback callback,
+                           gpointer callback_data)
 {
 	NMConnection *connection;
 	NMSettingWired *s_wired = NULL;
@@ -89,7 +90,8 @@ wired_new_auto_connection (NMDevice *device,
 
 	nm_connection_add_setting (connection, NM_SETTING (s_con));
 
-	return connection;
+	(*callback) (connection, TRUE, FALSE, callback_data);
+	return TRUE;
 }
 
 static void
@@ -648,7 +650,10 @@ get_8021x_secrets_cb (GtkDialog *dialog,
 		goto done;
 	}
 
+	utils_fill_connection_certs (NM_CONNECTION (connection));
 	secrets = nm_setting_to_hash (setting);
+	utils_clear_filled_connection_certs (NM_CONNECTION (connection));
+
 	if (!secrets) {
 		g_set_error (&err, NM_SETTINGS_ERROR, NM_SETTINGS_ERROR_INTERNAL_ERROR,
 					 "%s.%d (%s): failed to hash setting '%s'.",
@@ -656,9 +661,6 @@ get_8021x_secrets_cb (GtkDialog *dialog,
 		goto done;
 	}
 
-	utils_fill_connection_certs (connection);
-	utils_clear_filled_connection_certs (connection);
-
 	/* Returned secrets are a{sa{sv}}; this is the outer a{s...} hash that
 	 * will contain all the individual settings hashes.
 	 */
